@@ -1,6 +1,6 @@
 `valTable` <-
 function (x, method = c("simple", "onedims", "clustpppca", "addNoise: additive", "swappNum"), measure = "mean", 
-    clustermethod = "Mclust", aggr = 3, nc = 8, transf = "log", p=15, noise=15, w=1:dim(x)[2], delta=0.1) 
+    clustermethod = "clara", aggr = 3, nc = 8, transf = "log", p=15, noise=15, w=1:dim(x)[2], delta=0.1) 
 {
 `prcompRob` <-
 function (X, k = 0, sca = "mad", scores = TRUE) 
